@@ -41,7 +41,7 @@
  * @author blueyed: Daniel HAHLER.
  * @author fplanque: Francois PLANQUE.
  *
- * @version $Id: files.ctrl.php,v 1.12 2008/02/04 13:57:50 fplanque Exp $
+ * @version $Id: files.ctrl.php,v 1.12.4.1 2008/09/29 04:32:54 fplanque Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -156,6 +156,10 @@ if( $fm_FileRoot )
 	}
 	else
 	{ // Root exists
+
+		// Make sure $root is set:
+		$root = $fm_FileRoot->ID;
+
 		// Let's get into requested list dir...
 		$non_canonical_list_path = $fm_FileRoot->ads_path.$path;
 
