@@ -29,7 +29,7 @@
  * @author blueyed: Daniel HAHLER.
  * @author fplanque: Francois PLANQUE.
  *
- * @version $Id: _file.class.php,v 1.4 2008/01/21 09:35:28 fplanque Exp $
+ * @version $Id: _file.class.php,v 1.4.2.1 2008/09/15 11:02:38 fplanque Exp $
  *
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
@@ -1764,6 +1764,28 @@ class File extends DataObject
 			imagepng( $im_handle );
 		}
 	}
+
+
+  /**
+	 * @param Item
+	 */
+	function link_to_Item( & $edited_Item )
+	{
+		global $DB;
+
+		$DB->begin();
+
+		// Load meta data AND MAKE SURE IT IS CREATED IN DB:
+		$this->load_meta( true );
+
+		// Let's make the link!
+		$edited_Link = & new Link();
+		$edited_Link->set( 'itm_ID', $edited_Item->ID );
+		$edited_Link->set( 'file_ID', $this->ID );
+		$edited_Link->dbinsert();
+
+		$DB->commit();
+	}
 }
 
 
