@@ -192,6 +192,9 @@ function install_basic_skins()
 	$Skin = new Skin();
 	$Skin->install( 'custom' );
 
+	$Skin = new Skin();
+	$Skin->install( 'glossyblue' );
+
 	$Skin = new Skin();
 	$Skin->install( 'natural_pink' );
 
@@ -337,13 +340,17 @@ function install_basic_widgets()
 							 SELECT blog_ID, "Sidebar", 8, "core", "coll_xml_feeds"
 							   FROM T_blogs' );
 
-	// Add Tag Cloud to all blog Sidebar2:
-	$DB->query( 'INSERT INTO T_widget( wi_coll_ID, wi_sco_name, wi_order, wi_type, wi_code, wi_params )
-							 SELECT blog_ID, "Sidebar 2", 1, "core", "free_html", \'a:5:{s:5:"title";s:9:"Sidebar 2";s:7:"content";s:162:"This is the "Sidebar 2" container. You can place any widget you like in here. In the evo toolbar at the top of this page, select "Customize", then "Blog Widgets".";s:11:"widget_name";s:9:"Free HTML";s:16:"widget_css_class";s:0:"";s:9:"widget_ID";s:0:"";}\'
+	// All blog Sidebar 2:
+	$DB->query( 'INSERT INTO T_widget( wi_coll_ID, wi_sco_name, wi_order, wi_type, wi_code )
+							 SELECT blog_ID, "Sidebar 2", 1, "core", "coll_post_list"
 							   FROM T_blogs' );
 
 	$DB->query( 'INSERT INTO T_widget( wi_coll_ID, wi_sco_name, wi_order, wi_type, wi_code )
-							 SELECT blog_ID, "Sidebar 2", 2, "core", "coll_post_list"
+							 SELECT blog_ID, "Sidebar 2", 2, "core", "coll_comment_list"
+							   FROM T_blogs' );
+
+	$DB->query( 'INSERT INTO T_widget( wi_coll_ID, wi_sco_name, wi_order, wi_type, wi_code, wi_params )
+							 SELECT blog_ID, "Sidebar 2", 3, "core", "free_html", \'a:5:{s:5:"title";s:9:"Sidebar 2";s:7:"content";s:162:"This is the "Sidebar 2" container. You can place any widget you like in here. In the evo toolbar at the top of this page, select "Customize", then "Blog Widgets".";s:11:"widget_name";s:9:"Free HTML";s:16:"widget_css_class";s:0:"";s:9:"widget_ID";s:0:"";}\'
 							   FROM T_blogs' );
 
 	echo "OK.<br />\n";
